@@ -36,6 +36,7 @@ gchar *get_complete_address		(gint		 index);
 
 gchar *get_next_complete_address	(void);
 gchar *get_prev_complete_address	(void);
+guint get_completion_count		(void);
 
 gboolean is_completion_pending		(void);
 
@@ -43,4 +44,10 @@ void clear_completion_cache		(void);
 
 gint end_address_completion		(void);
 
+/* ui functions */
+
+void address_completion_start	(GtkWidget *mainwindow);
+void address_completion_register_entry	(GtkEntry *entry);
+void address_completion_end	(GtkWidget *mainwindow);
+
 #endif /* __ADDR_COMPL_H__ */
