@@ -114,6 +114,12 @@ struct _Folder
 	gint     (*move_msgs_with_dest)	(Folder		*folder,
 					 FolderItem	*dest,
 					 GSList		*msglist);
+	gint     (*copy_msg)		(Folder		*folder,
+					 FolderItem	*dest,
+					 MsgInfo	*msginfo);
+	gint     (*copy_msgs_with_dest)	(Folder		*folder,
+					 FolderItem	*dest,
+					 GSList		*msglist);
 	gint     (*remove_msg)		(Folder		*folder,
 					 FolderItem	*item,
 					 gint		 num);
@@ -253,6 +259,10 @@ gint   folder_item_move_msg		(FolderItem	*dest,
 					 MsgInfo	*msginfo);
 gint   folder_item_move_msgs_with_dest	(FolderItem	*dest,
 					 GSList		*msglist);
+gint   folder_item_copy_msg		(FolderItem	*dest,
+					 MsgInfo	*msginfo);
+gint   folder_item_copy_msgs_with_dest	(FolderItem	*dest,
+					 GSList		*msglist);
 gint   folder_item_remove_msg		(FolderItem	*item,
 					 gint		 num);
 gint   folder_item_remove_all_msg	(FolderItem	*item);
