@@ -74,4 +74,8 @@ void folderview_update_item		(FolderItem	*item,
 					 gboolean	 update_summary);
 void folderview_update_item_foreach	(GHashTable	*table);
 
+void folderview_new_folder		(FolderView	*folderview);
+void folderview_rename_folder		(FolderView	*folderview);
+void folderview_delete_folder		(FolderView	*folderview);
+
 #endif /* __FOLDERVIEW_H__ */
