@@ -59,6 +59,9 @@
 gint gtkut_get_font_width		(GdkFont	*font);
 gint gtkut_get_font_height		(GdkFont	*font);
 
+void gtkut_convert_int_to_gdk_color	(gint		 rgbvalue,
+					 GdkColor	*color);
+
 void gtkut_button_set_create		(GtkWidget	**bbox,
 					 GtkWidget	**button1,
 					 const gchar	 *label1,
@@ -86,4 +89,6 @@ void gtkut_widget_get_uposition		(GtkWidget	*widget,
 					 gint		*px,
 					 gint		*py);
 
+void gtkut_widget_init			(void);
+
 #endif /* __GTKUTILS_H__ */
