@@ -98,7 +98,7 @@ static gint connection_check_cb		(Automaton	*atm);
 #endif
 
 static void inc_pop3_recv_func		(SockInfo	*sock,
-					 gint		 read_len,
+					 gint		 read_bytes,
 					 gpointer	 data);
 
 static void inc_put_error		(IncState	 istate);
@@ -110,6 +110,7 @@ static gint inc_spool			(void);
 static gint get_spool			(FolderItem	*dest,
 					 const gchar	*mbox);
 
+static gint inc_autocheck_func		(gpointer	 data);
 
 static void inc_finished(MainWindow *mainwin)
 {
@@ -130,6 +131,7 @@ static void inc_finished(MainWindow *mainwin)
 
 void inc_mail(MainWindow *mainwin)
 {
+	inc_autocheck_timer_remove();
 	summary_write_cache(mainwin->summaryview);
 
 	if (prefs_common.use_extinc && prefs_common.extinc_path) {
@@ -138,6 +140,7 @@ void inc_mail(MainWindow *mainwin)
 		/* external incorporating program */
 		if ((pid = fork()) < 0) {
 			perror("fork");
+			inc_autocheck_timer_set();
 			return;
 		}
 
@@ -162,6 +165,7 @@ void inc_mail(MainWindow *mainwin)
 	}
 
 	inc_finished(mainwin);
+	inc_autocheck_timer_set();
 }
 
 static void inc_account_mail(PrefsAccount *account, MainWindow *mainwin)
@@ -191,12 +195,16 @@ void inc_all_account_mail(MainWindow *mainwin)
 	GList *list, *queue_list = NULL;
 	IncProgressDialog *inc_dialog;
 
+	inc_autocheck_timer_remove();
 	summary_write_cache(mainwin->summaryview);
 
 	if (prefs_common.inc_local) inc_spool();
 
 	list = account_get_list();
-	if (!list) return;
+	if (!list) {
+		inc_autocheck_timer_set();
+		return;
+	}
 
 	for (; list != NULL; list = list->next) {
 		IncSession *session;
@@ -209,7 +217,10 @@ void inc_all_account_mail(MainWindow *mainwin)
 		}
 	}
 
-	if (!queue_list) return;
+	if (!queue_list) {
+		inc_autocheck_timer_set();
+		return;
+	}
 
 	inc_dialog = inc_progress_dialog_create();
 	inc_dialog->queue_list = queue_list;
@@ -229,6 +240,7 @@ void inc_all_account_mail(MainWindow *mainwin)
 	inc_start(inc_dialog);
 
 	inc_finished(mainwin);
+	inc_autocheck_timer_set();
 }
 
 static IncProgressDialog *inc_progress_dialog_create(void)
@@ -510,7 +522,7 @@ static IncState inc_pop3_session_do(IncSession *session)
 #if USE_THREADS
 	if ((sockinfo = sock_connect_with_thread(server, port)) == NULL) {
 #else
-	if ((sockinfo = sock_connect_nb(server, port)) == NULL) {
+	if ((sockinfo = sock_connect(server, port)) == NULL) {
 #endif
 		log_warning(_("Can't connect to POP3 server: %s:%d\n"),
 			    server, port);
@@ -665,7 +677,7 @@ static gint connection_check_cb(Automaton *atm)
 }
 #endif
 
-static void inc_pop3_recv_func(SockInfo *sock, gint read_len, gpointer data)
+static void inc_pop3_recv_func(SockInfo *sock, gint read_bytes, gpointer data)
 {
 	gchar buf[MSGBUFSIZE];
 	IncSession *session = (IncSession *)data;
@@ -674,8 +686,7 @@ static void inc_pop3_recv_func(SockInfo *sock, gint read_len, gpointer data)
 	ProgressDialog *dialog = inc_dialog->dialog;
 	gint cur_total;
 
-	state->cur_msg_bytes += read_len;
-	cur_total = state->cur_total_bytes + state->cur_msg_bytes;
+	cur_total = state->cur_total_bytes + read_bytes;
 	if (cur_total > state->total_bytes)
 		cur_total = state->total_bytes;
 
@@ -705,16 +716,27 @@ void inc_progress_update(Pop3State *state, Pop3Phase phase)
 	case POP3_GETAUTH_PASS_RECV:
 	case POP3_GETAUTH_APOP_SEND:
 	case POP3_GETAUTH_APOP_RECV:
-		progress_dialog_set_label(dialog, _("Authorizing"));
+		progress_dialog_set_label(dialog, _("Authorizing..."));
 		break;
 	case POP3_GETRANGE_STAT_SEND:
 	case POP3_GETRANGE_STAT_RECV:
+		progress_dialog_set_label
+			(dialog, _("Getting the number of new messages (STAT)..."));
+		break;
 	case POP3_GETRANGE_LAST_SEND:
 	case POP3_GETRANGE_LAST_RECV:
+		progress_dialog_set_label
+			(dialog, _("Getting the number of new messages (LAST)..."));
+		break;
 	case POP3_GETRANGE_UIDL_SEND:
 	case POP3_GETRANGE_UIDL_RECV:
-		progress_dialog_set_label(dialog,
-					  _("Getting number of new messages"));
+		progress_dialog_set_label
+			(dialog, _("Getting the number of new messages (UIDL)..."));
+		break;
+	case POP3_GETSIZE_LIST_SEND:
+	case POP3_GETSIZE_LIST_RECV:
+		progress_dialog_set_label
+			(dialog, _("Getting the size of messages (LIST)..."));
 		break;
 	case POP3_RETR_SEND:
 	case POP3_RETR_RECV:
@@ -836,7 +858,7 @@ static gint get_spool(FolderItem *dest, const gchar *mbox)
 {
 	gint msgs, size;
 	gint lockfd;
-	gchar *tmp_mbox = "/tmp/tmpmbox";
+	gchar tmp_mbox[MAXPATHLEN + 1];
 	GHashTable *folder_table = NULL;
 
 	g_return_val_if_fail(dest != NULL, -1);
@@ -851,6 +873,9 @@ static gint get_spool(FolderItem *dest, const gchar *mbox)
 	if ((lockfd = lock_mbox(mbox, LOCK_FLOCK)) < 0)
 		return -1;
 
+	g_snprintf(tmp_mbox, sizeof(tmp_mbox), "%s%ctmpmbox%d",
+		   get_rc_dir(), G_DIR_SEPARATOR, (gint)mbox);
+
 	if (copy_mbox(mbox, tmp_mbox) < 0)
 		return -1;
 
@@ -875,4 +900,42 @@ static gint get_spool(FolderItem *dest, const gchar *mbox)
 	}
 
 	return msgs;
-}
\ No newline at end of file
+}
+
+static guint autocheck_timer = 0;
+static gpointer autocheck_data = NULL;
+
+void inc_autocheck_timer_init(MainWindow *mainwin)
+{
+	autocheck_data = mainwin;
+	inc_autocheck_timer_set();
+}
+
+void inc_autocheck_timer_set(void)
+{
+	inc_autocheck_timer_remove();
+
+	if (prefs_common.autochk_newmail && autocheck_data) {
+		autocheck_timer = gtk_timeout_add
+			(prefs_common.autochk_itv * 60000,
+			 inc_autocheck_func,
+			 autocheck_data);
+	}
+}
+
+void inc_autocheck_timer_remove(void)
+{
+	if (autocheck_timer) {
+		gtk_timeout_remove(autocheck_timer);
+		autocheck_timer = 0;
+	}
+}
+
+static gint inc_autocheck_func(gpointer data)
+{
+	MainWindow *mainwin = (MainWindow *)data;
+
+	inc_all_account_mail(mainwin);
+
+	return FALSE;
+}
