@@ -47,13 +47,16 @@
 #include "summaryview.h"
 #include "summary_search.h"
 #include "messageview.h"
+#include "headerview.h"
 #include "menu.h"
 #include "folder.h"
 #include "inc.h"
 #include "compose.h"
 #include "procmsg.h"
 #include "import.h"
+#include "export.h"
 #include "prefs_common.h"
+#include "prefs_filter.h"
 #include "prefs_account.h"
 #include "account.h"
 #include "addressbook.h"
@@ -155,6 +158,9 @@ static void delete_folder_cb	 (MainWindow	*mainwin,
 static void import_mbox_cb	 (MainWindow	*mainwin,
 				  guint		 action,
 				  GtkWidget	*widget);
+static void export_mbox_cb	 (MainWindow	*mainwin,
+				  guint		 action,
+				  GtkWidget	*widget);
 static void empty_trash_cb	 (MainWindow	*mainwin,
 				  guint		 action,
 				  GtkWidget	*widget);
@@ -301,6 +307,9 @@ static void allsel_cb		 (MainWindow	*mainwin,
 static void prefs_common_open_cb (MainWindow	*mainwin,
 				  guint		 action,
 				  GtkWidget	*widget);
+static void prefs_filter_open_cb (MainWindow	*mainwin,
+				  guint		 action,
+				  GtkWidget	*widget);
 static void prefs_account_open_cb(MainWindow	*mainwin,
 				  guint		 action,
 				  GtkWidget	*widget);
@@ -330,6 +339,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_File/_Folder/_Rename folder..."),NULL, rename_folder_cb, 0, NULL},
 	{N_("/_File/_Folder/_Delete folder"),	NULL, delete_folder_cb, 0, NULL},
 	{N_("/_File/_Import mbox file..."),	NULL, import_mbox_cb, 0, NULL},
+	{N_("/_File/_Export to mbox file..."),	NULL, export_mbox_cb, 0, NULL},
 	{N_("/_File/Empty _trash"),		NULL, empty_trash_cb, 0, NULL},
 	{N_("/_File/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_File/_Save as..."),		NULL, save_as_cb, 0, NULL},
@@ -428,6 +438,9 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	 CODESET_ACTION(C_ISO_2022_KR)},
 #endif
 
+#undef CODESET_SEPARATOR
+#undef CODESET_ACTION
+
 	{N_("/_Message"),			NULL, NULL, 0, "<Branch>"},
 	{N_("/_Message/Rece_ive new mail"),	"<alt>I",	inc_mail_cb, 0, NULL},
 	{N_("/_Message/Receive from _all accounts"),
@@ -492,6 +505,8 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Configuration"),			NULL, NULL, 0, "<Branch>"},
 	{N_("/_Configuration/_Common preferences..."),
 						NULL, prefs_common_open_cb, 0, NULL},
+	{N_("/_Configuration/_Filter setting..."),
+						NULL, prefs_filter_open_cb, 0, NULL},
 	{N_("/_Configuration/_Preferences per account..."),
 						NULL, prefs_account_open_cb, 0, NULL},
 	{N_("/_Configuration/---"),		NULL, NULL, 0, "<Separator>"},
@@ -768,6 +783,9 @@ void main_window_reflect_prefs_all(void)
 		}
 
 		summary_change_display_item(mainwin->summaryview);
+		summary_redisplay_msg(mainwin->summaryview);
+		headerview_set_visibility(mainwin->messageview->headerview,
+					  prefs_common.display_header_pane);
 	}
 }
 
@@ -925,6 +943,7 @@ void main_window_empty_trash(MainWindow *mainwin, gboolean confirm)
 			       _("Empty all messages in trash?"),
 			       _("Yes"), _("No"), NULL) != G_ALERTDEFAULT)
 			return;
+		manage_window_focus_in(mainwin->window, NULL, NULL);
 	}
 
 	procmsg_empty_trash();
@@ -1604,7 +1623,13 @@ static void delete_folder_cb(MainWindow *mainwin, guint action,
 static void import_mbox_cb(MainWindow *mainwin, guint action,
 			   GtkWidget *widget)
 {
-	import_mbox();
+	import_mbox(mainwin->summaryview->folder_item);
+}
+
+static void export_mbox_cb(MainWindow *mainwin, guint action,
+			   GtkWidget *widget)
+{
+	export_mbox(mainwin->summaryview->folder_item);
 }
 
 static void empty_trash_cb(MainWindow *mainwin, guint action,
@@ -1629,9 +1654,9 @@ static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
 		if (alertpanel(_("Exit"), _("Exit this program?"),
 			       _("OK"), _("Cancel"), NULL) != G_ALERTDEFAULT)
 			return;
+		manage_window_focus_in(mainwin->window, NULL, NULL);
 	}
 
-	manage_window_focus_in(mainwin->window, NULL, NULL);
 	app_will_exit(widget, mainwin);
 }
 
@@ -1997,6 +2022,12 @@ static void prefs_common_open_cb(MainWindow *mainwin, guint action,
 	prefs_common_open();
 }
 
+static void prefs_filter_open_cb(MainWindow *mainwin, guint action,
+				 GtkWidget *widget)
+{
+	prefs_filter_open();
+}
+
 static void prefs_account_open_cb(MainWindow *mainwin, guint action,
 				  GtkWidget *widget)
 {
