@@ -68,7 +68,7 @@ Session *news_session_new(const gchar *server, gushort port)
 {
 	gchar buf[NNTPBUFSIZE];
 	NNTPSession *session;
-	gint nntp_sock;
+	SockInfo *nntp_sock;
 
 	g_return_val_if_fail(server != NULL, NULL);
 
@@ -91,7 +91,8 @@ Session *news_session_new(const gchar *server, gushort port)
 
 void news_session_destroy(NNTPSession *session)
 {
-	close(SESSION(session)->sock);
+	sock_close(SESSION(session)->sock);
+	SESSION(session)->sock = NULL;
 
 	g_free(session->group);
 }
@@ -321,7 +322,7 @@ static GSList *news_get_uncached_articles(NNTPSession *session,
 	}
 
 	for (;;) {
-		if (sock_read(SESSION(session)->sock, buf, sizeof(buf)) < 0) {
+		if (sock_gets(SESSION(session)->sock, buf, sizeof(buf)) < 0) {
 			log_warning(_("error occurred while getting xover.\n"));
 			return newlist;
 		}
