@@ -39,6 +39,7 @@
 #include "account.h"
 #include "mainwindow.h"
 #include "manage_window.h"
+#include "inc.h"
 #include "menu.h"
 #include "gtkutils.h"
 #include "utils.h"
@@ -290,6 +291,9 @@ static void prefs_account_privacy_create	(void);
 #endif /* USE_GPGME */
 static void prefs_account_advanced_create	(void);
 
+static gint prefs_account_deleted		(GtkWidget	*widget,
+						 GdkEventAny	*event,
+						 gpointer	 data);
 static void prefs_account_key_pressed		(GtkWidget	*widget,
 						 GdkEventKey	*event,
 						 gpointer	 data);
@@ -397,6 +401,8 @@ PrefsAccount *prefs_account_open(PrefsAccount *ac_prefs)
 
 	debug_print(_("Opening account preferences window...\n"));
 
+	inc_autocheck_timer_remove();
+
 	cancelled = FALSE;
 
 	if (!ac_prefs) {
@@ -446,6 +452,8 @@ PrefsAccount *prefs_account_open(PrefsAccount *ac_prefs)
 	gtk_main();
 	gtk_widget_hide(dialog.window);
 
+	inc_autocheck_timer_set();
+
 	if (cancelled && new_account) {
 		g_free(ac_prefs);
 		return NULL;
@@ -464,7 +472,7 @@ static void prefs_account_create(void)
 	/* create dialog */
 	prefs_dialog_create(&dialog);
 	gtk_signal_connect(GTK_OBJECT(dialog.window), "delete_event",
-			   GTK_SIGNAL_FUNC(prefs_account_cancel), NULL);
+			   GTK_SIGNAL_FUNC(prefs_account_deleted), NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog.window), "key_press_event",
 			   GTK_SIGNAL_FUNC(prefs_account_key_pressed), NULL);
 	gtk_signal_connect(GTK_OBJECT(dialog.window), "focus_in_event",
@@ -765,8 +773,9 @@ static void prefs_account_receive_create(void)
 			   _("Remove messages on server when received"));
 	PACK_CHECK_BUTTON (vbox2, getall_chkbtn,
 			   _("Receive all messages on server"));
-	PACK_CHECK_BUTTON (vbox2, recvatgetall_chkbtn,
-			   _("Receive at getting from all accounts"));
+	PACK_CHECK_BUTTON
+		(vbox2, recvatgetall_chkbtn,
+		 _("`Receive all' checks for new mail on this account"));
 	PACK_CHECK_BUTTON (vbox2, filter_on_recv_chkbtn,
 			   _("Filter messages on receiving"));
 
@@ -1078,6 +1087,13 @@ static void prefs_account_advanced_create(void)
 	advanced.domain_entry		= entry_domain;
 }
 
+static gint prefs_account_deleted(GtkWidget *widget, GdkEventAny *event,
+				  gpointer data)
+{
+	prefs_account_cancel();
+	return TRUE;
+}
+
 static void prefs_account_key_pressed(GtkWidget *widget, GdkEventKey *event,
 				      gpointer data)
 {
