@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2001 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -165,6 +165,7 @@ GSList *procmsg_read_cache(FolderItem *item, gboolean scan_file)
 	FILE *fp;
 	MsgInfo *msginfo;
 	MsgFlags default_flags;
+	gchar file_buf[BUFFSIZE];
 	gint ver;
 	guint num;
 	FolderType type;
@@ -202,6 +203,7 @@ GSList *procmsg_read_cache(FolderItem *item, gboolean scan_file)
 		g_free(cache_file);
 		return NULL;
 	}
+	setvbuf(fp, file_buf, _IOFBF, sizeof(file_buf));
 	g_free(cache_file);
 
 	debug_print(_("\tReading summary cache..."));
@@ -264,6 +266,7 @@ void procmsg_set_flags(GSList *mlist, FolderItem *item)
 {
 	GSList *cur, *tmp;
 	gint newmsg = 0;
+	gint lastnum = 0;
 	gchar *markdir;
 	MsgInfo *msginfo;
 	GHashTable *mark_table;
@@ -284,17 +287,18 @@ void procmsg_set_flags(GSList *mlist, FolderItem *item)
 	for (cur = mlist; cur != NULL; cur = cur->next) {
 		msginfo = (MsgInfo *)cur->data;
 
+		if (lastnum < msginfo->msgnum)
+			lastnum = msginfo->msgnum;
+
 		flags = GPOINTER_TO_UINT(g_hash_table_lookup(mark_table,
 					 GUINT_TO_POINTER(msginfo->msgnum)));
 
 		if (flags != 0) {
-			/* flag found */
-			/* preserve several flags */
-			msginfo->flags &=
-				(MSG_QUEUED|MSG_DRAFT|MSG_MIME|MSG_CACHED);
-			msginfo->flags |=
-				(flags &
-				 ~(MSG_QUEUED|MSG_DRAFT|MSG_MIME|MSG_CACHED));
+			/* add the permanent flags only */
+			MSG_UNSET_FLAGS(msginfo->flags,
+					MSG_PERMANENT_FLAG_MASK);
+			MSG_SET_FLAGS(msginfo->flags,
+				      flags & MSG_PERMANENT_FLAG_MASK);
 			if (item->folder->type == F_IMAP) {
 				MSG_SET_FLAGS(msginfo->flags, MSG_IMAP);
 			} else if (item->folder->type == F_NEWS) {
@@ -312,6 +316,8 @@ void procmsg_set_flags(GSList *mlist, FolderItem *item)
 		}
 	}
 
+	item->last_num = lastnum;
+
 	debug_print(_("done.\n"));
 	if (newmsg)
 		debug_print(_("\t%d new message(s)\n"), newmsg);
@@ -338,7 +344,7 @@ gint procmsg_get_last_num_in_cache(GSList *mlist)
 
 void procmsg_write_cache(MsgInfo *msginfo, FILE *fp)
 {
-	MsgFlags flags = msginfo->flags & MSG_MIME;
+	MsgFlags flags = msginfo->flags & MSG_CACHED_FLAG_MASK;
 
 	WRITE_CACHE_DATA_INT(msginfo->msgnum, fp);
 	WRITE_CACHE_DATA_INT(msginfo->size, fp);
@@ -361,7 +367,7 @@ void procmsg_write_flags(MsgInfo *msginfo, FILE *fp)
 {
 	MsgFlags flags;
 
-	flags = msginfo->flags & (MSG_NEW|MSG_UNREAD|MSG_IMPORTANT);
+	flags = msginfo->flags & MSG_PERMANENT_FLAG_MASK;
 
 	WRITE_CACHE_DATA_INT(msginfo->msgnum, fp);
 	WRITE_CACHE_DATA_INT(flags, fp);
@@ -505,6 +511,41 @@ void procmsg_move_messages(GSList *mlist)
 	}
 }
 
+void procmsg_copy_messages(GSList *mlist)
+{
+	GSList *cur, *copylist = NULL;
+	MsgInfo *msginfo;
+	FolderItem *dest = NULL;
+	GHashTable *hash;
+
+	if (!mlist) return;
+
+	hash = procmsg_to_folder_hash_table_create(mlist);
+	folder_item_scan_foreach(hash);
+	g_hash_table_destroy(hash);
+
+	for (cur = mlist; cur != NULL; cur = cur->next) {
+		msginfo = (MsgInfo *)cur->data;
+		if (!dest) {
+			dest = msginfo->to_folder;
+			copylist = g_slist_append(copylist, msginfo);
+		} else if (dest == msginfo->to_folder) {
+			copylist = g_slist_append(copylist, msginfo);
+		} else {
+			folder_item_copy_msgs_with_dest(dest, copylist);
+			g_slist_free(copylist);
+			copylist = NULL;
+			dest = msginfo->to_folder;
+			copylist = g_slist_append(copylist, msginfo);
+		}
+	}
+
+	if (copylist) {
+		folder_item_copy_msgs_with_dest(dest, copylist);
+		g_slist_free(copylist);
+	}
+}
+
 gchar *procmsg_get_message_file_path(MsgInfo *msginfo)
 {
 	gchar *path, *file;
@@ -579,7 +620,7 @@ gboolean procmsg_msg_exist(MsgInfo *msginfo)
 	return ret;
 }
 
-void procmsg_clean_trash(void)
+void procmsg_empty_trash(void)
 {
 	FolderItem *trash;
 	GList *cur;
