@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999,2000 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2001 Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
 #include "socket.h"
 
 typedef void (*RecvUIFunc)	(SockInfo	*sock,
-				 gint		 read_len,
+				 gint		 read_bytes,
 				 gpointer	 data);
 
 gint recv_write_to_file		(SockInfo	*sock,
