@@ -22,6 +22,8 @@
 
 #include <glib.h>
 
+#include "socket.h"
+
 typedef struct _Session	Session;
 
 #define SESSION(obj)	((Session *)obj)
@@ -41,7 +43,7 @@ struct _Session
 {
 	SessionType type;
 
-	gint   sock;
+	SockInfo *sock;
 	gchar *server;
 
 	gboolean connected;
