@@ -63,6 +63,7 @@
 #include "utils.h"
 #include "gtkutils.h"
 #include "filesel.h"
+#include "manage_window.h"
 #include "alertpanel.h"
 #include "inputdialog.h"
 #include "statusbar.h"
@@ -556,8 +557,11 @@ gboolean summary_show(SummaryView *summaryview, FolderItem *item,
 	STATUSBAR_POP(summaryview->mainwin);
 
 	is_refresh = (item == summaryview->folder_item) ? TRUE : FALSE;
-	if (is_refresh)
+	if (is_refresh) {
 		prev_msgnum = summary_get_current_msgnum(summaryview);
+		if (prev_msgnum < 1)
+			is_refresh = FALSE;
+	}
 
 #if 0
 	/* process the marks if any */
@@ -2207,7 +2211,9 @@ static void summary_execute_delete(SummaryView *summaryview)
 	GSList *cur;
 
 	trash = summaryview->folder_item->folder->trash;
-	g_return_if_fail(trash != NULL);
+	if (summaryview->folder_item->folder->type == F_MH) {
+		g_return_if_fail(trash != NULL);
+	}
 	if (summaryview->folder_item == trash) return;
 
 	/* search deleting messages and execute */
@@ -2517,6 +2523,9 @@ static void summary_key_pressed(GtkWidget *widget, GdkEventKey *event,
 			if (alertpanel(_("Exit"), _("Exit this program?"),
 				       _("OK"), _("Cancel"), NULL)
 				       == G_ALERTDEFAULT) {
+				manage_window_focus_in
+					(summaryview->mainwin->window,
+					 NULL, NULL);
 				app_will_exit(NULL, summaryview->mainwin);
 			}
 		}
