@@ -46,6 +46,7 @@
 #include "procmime.h"
 #include "html.h"
 #include "compose.h"
+#include "displayheader.h"
 
 #define FONT_LOAD(font, s) \
 { \
@@ -328,16 +329,8 @@ void textview_show_part(TextView *textview, MimeInfo *mimeinfo, FILE *fp)
 	gtk_text_freeze(text);
 
 	if (headers) {
-		gint i;
-
 		textview_show_header(textview, headers);
-		for (i = 0; i < headers->len; i++) {
-			Header *header = g_ptr_array_index(headers, i);
-			g_free(header->body);
-			g_free(header->name);
-			g_free(header);
-		}
-		g_ptr_array_free(headers, TRUE);
+		procheader_header_array_destroy(headers);
 	}
 
 	tmpfp = procmime_decode_content(NULL, fp, mimeinfo);
@@ -563,7 +556,8 @@ static gchar *make_email_string(const gchar *bp, const gchar *ep)
 	}
 
 /* textview_make_clickable_parts() - colorizes clickable parts */
-static void textview_make_clickable_parts(TextView *textview, GtkText *text,
+static void textview_make_clickable_parts(TextView *textview,
+					  GdkFont *font,
 					  GdkColor *fg_color,
 					  GdkColor *uri_color,
 					  const gchar *linebuf)
@@ -603,6 +597,8 @@ static void textview_make_clickable_parts(TextView *textview, GtkText *text,
 		struct txtpos	*next;		/* next */
 	} head = {NULL, NULL, 0,  NULL}, *last = &head;
 
+	GtkText *text = GTK_TEXT(textview->text);
+
 	/* parse for clickable parts, and build a list of begin and end positions  */
 	for (walk = linebuf, n = 0;;) {
 		gint last_index = PARSE_ELEMS;
@@ -624,7 +620,7 @@ static void textview_make_clickable_parts(TextView *textview, GtkText *text,
 		if (scanpos) {
 			/* check if URI can be parsed */
 			if (parser[last_index].parse(linebuf, scanpos, &bp, &ep)
-			    && (ep - bp - 1) > strlen(parser[n].needle)) {
+			    && (ep - bp - 1) > strlen(parser[last_index].needle)) {
 					ADD_TXT_POS(bp, ep, last_index);
 					walk = ep;
 			} else
@@ -645,13 +641,14 @@ static void textview_make_clickable_parts(TextView *textview, GtkText *text,
 
 			uri = g_new(RemoteURI, 1);
 			if (last->bp - normal_text > 0)
-				gtk_text_insert(text, textview->msgfont,
+				gtk_text_insert(text, font,
 						fg_color, NULL,
 						normal_text,
 						last->bp - normal_text);
-			uri->uri = parser[last->pti].build_uri(last->bp, last->ep);
+			uri->uri = parser[last->pti].build_uri(last->bp,
+							       last->ep);
 			uri->start = gtk_text_get_point(text);
-			gtk_text_insert(text, textview->msgfont, uri_color,
+			gtk_text_insert(text, font, uri_color,
 					NULL, last->bp, last->ep - last->bp);
 			uri->end = gtk_text_get_point(text);
 			textview->uri_list =
@@ -659,11 +656,10 @@ static void textview_make_clickable_parts(TextView *textview, GtkText *text,
 		}
 
 		if (*normal_text)
-			gtk_text_insert(text, textview->msgfont, fg_color,
+			gtk_text_insert(text, font, fg_color,
 					NULL, normal_text, -1);
 	} else
-		gtk_text_insert(text, textview->msgfont, fg_color, NULL,
-				linebuf, -1);
+		gtk_text_insert(text, font, fg_color, NULL, linebuf, -1);
 }
 
 #undef ADD_TXT_POS
@@ -722,7 +718,7 @@ static void textview_write_line(TextView *textview, const gchar *str,
 		gtk_text_insert(text, spacingfont, NULL, NULL, " ", 1);
 
 	if (prefs_common.enable_color)
-		textview_make_clickable_parts(textview, text,
+		textview_make_clickable_parts(textview, textview->msgfont,
 					      fg_color, &uri_color, buf);
 	else
 		gtk_text_insert(text, textview->msgfont, fg_color, NULL,
@@ -770,11 +766,11 @@ void textview_set_font(TextView *textview, const gchar *codeset)
 	   correctly, so it must be single-byte mode. */
 	if (MB_CUR_MAX > 1) {
 		if (codeset) {
-			if (!strncasecmp(codeset, "ISO-8859-", 9) ||
-			    !strncasecmp(codeset, "KOI8-", 5)     ||
-			    !strncasecmp(codeset, "CP", 2)        ||
-			    !strncasecmp(codeset, "WINDOWS-", 8)  ||
-			    !strcasecmp(codeset, "BALTIC"))
+			if (!g_strncasecmp(codeset, "ISO-8859-", 9) ||
+			    !g_strncasecmp(codeset, "KOI8-", 5)     ||
+			    !g_strncasecmp(codeset, "CP", 2)        ||
+			    !g_strncasecmp(codeset, "WINDOWS-", 8)  ||
+			    !g_strcasecmp(codeset, "BALTIC"))
 				use_fontset = FALSE;
 		}
 	} else
@@ -846,41 +842,13 @@ void textview_set_font(TextView *textview, const gchar *codeset)
 		spacingfont = gdk_font_load("-*-*-medium-r-normal--6-*");
 }
 
-enum
-{
-	H_DATE		= 0,
-	H_FROM		= 1,
-	H_TO		= 2,
-	H_NEWSGROUPS	= 3,
-	H_SUBJECT	= 4,
-	H_CC		= 5,
-	H_REPLY_TO	= 6,
-	H_FOLLOWUP_TO	= 7,
-	H_X_MAILER	= 8,
-	H_X_NEWSREADER	= 9,
-	H_USER_AGENT	= 10,
-	H_ORGANIZATION	= 11,
-};
-
 static GPtrArray *textview_scan_header(TextView *textview, FILE *fp)
 {
-	static HeaderEntry hentry[] = {{"Date:",         NULL, FALSE},
-				       {"From:",         NULL, TRUE},
-				       {"To:",	         NULL, FALSE},
-				       {"Newsgroups:",   NULL, FALSE},
-				       {"Subject:",      NULL, TRUE},
-				       {"Cc:",	         NULL, FALSE},
-				       {"Reply-To:",     NULL, FALSE},
-				       {"Followup-To:",  NULL, FALSE},
-				       {"X-Mailer:",     NULL, TRUE},
-				       {"X-Newsreader:", NULL, TRUE},
-				       {"User-Agent:",   NULL, TRUE},
-				       {"Organization:", NULL, TRUE},
-				       {NULL,	         NULL, FALSE}};
-	gchar buf[BUFFSIZE], tmp[BUFFSIZE];
-	gint hnum;
-	HeaderEntry *hp;
-	GPtrArray *headers;
+	gchar buf[BUFFSIZE];
+	GPtrArray *headers, *sorted_headers;
+	GSList *disphdr_list;
+	Header *header;
+	gint i;
 
 	g_return_val_if_fail(fp != NULL, NULL);
 
@@ -890,24 +858,40 @@ static GPtrArray *textview_scan_header(TextView *textview, FILE *fp)
 		return NULL;
 	}
 
-	headers = g_ptr_array_new();
+	headers = procheader_get_header_array_asis(fp);
 
-	while ((hnum = procheader_get_one_field(buf, sizeof(buf), fp, hentry))
-	       != -1) {
-		Header *header;
+	sorted_headers = g_ptr_array_new();
 
-		hp = hentry + hnum;
+	for (disphdr_list = prefs_common.disphdr_list; disphdr_list != NULL;
+	     disphdr_list = disphdr_list->next) {
+		DisplayHeaderProp *dp =
+			(DisplayHeaderProp *)disphdr_list->data;
 
-		header = g_new(Header, 1);
-		header->name = g_strndup(buf, strlen(hp->name));
-		conv_unmime_header(tmp, sizeof(tmp), buf + strlen(hp->name),
-				   NULL);
-		header->body = g_strdup(tmp);
+		for (i = 0; i < headers->len; i++) {
+			header = g_ptr_array_index(headers, i);
 
-		g_ptr_array_add(headers, header);
+			if (!g_strcasecmp(header->name, dp->name)) {
+				if (dp->hidden)
+					procheader_header_free(header);
+				else
+					g_ptr_array_add(sorted_headers, header);
+
+				g_ptr_array_remove_index(headers, i);
+				i--;
+			}
+		}
 	}
 
-	return headers;
+	if (prefs_common.show_other_header) {
+		for (i = 0; i < headers->len; i++) {
+			header = g_ptr_array_index(headers, i);
+			g_ptr_array_add(sorted_headers, header);
+		}
+	}
+
+	g_ptr_array_free(headers, TRUE);
+
+	return sorted_headers;
 }
 
 static void textview_show_header(TextView *textview, GPtrArray *headers)
@@ -926,15 +910,28 @@ static void textview_show_header(TextView *textview, GPtrArray *headers)
 
 		gtk_text_insert(text, textview->boldfont, NULL, NULL,
 				header->name, -1);
+		gtk_text_insert(text, textview->boldfont, NULL, NULL, ":", 2);
+
+		if (!g_strcasecmp(header->name, "Subject") ||
+		    !g_strcasecmp(header->name, "From")    ||
+		    !g_strcasecmp(header->name, "To")      ||
+		    !g_strcasecmp(header->name, "Cc"))
+			unfold_line(header->body);
+
 		if (prefs_common.enable_color &&
-		    (strncmp(header->name, "X-Mailer", 8) == 0 ||
-		     strncmp(header->name, "X-Newsreader", 12) == 0) &&
+		    (!strncmp(header->name, "X-Mailer", 8) ||
+		     !strncmp(header->name, "X-Newsreader", 12)) &&
 		    strstr(header->body, "Sylpheed") != NULL)
 			gtk_text_insert(text, NULL, &emphasis_color, NULL,
 					header->body, -1);
-		else
+		else if (prefs_common.enable_color) {
+			textview_make_clickable_parts(textview,
+						      NULL, NULL, &uri_color,
+						      header->body);
+		} else {
 			gtk_text_insert(text, NULL, NULL, NULL,
 					header->body, -1);
+		}
 		gtk_text_insert(text, textview->msgfont, NULL, NULL, "\n", 1);
 	}
 
@@ -1174,7 +1171,7 @@ static void textview_button_pressed(GtkWidget *widget, GdkEventButton *event,
 
 			if (current_pos >= uri->start &&
 			    current_pos <  uri->end) {
-				if (!strncasecmp(uri->uri, "mailto:", 7))
+				if (!g_strncasecmp(uri->uri, "mailto:", 7))
 					compose_new_with_recipient
 						(NULL, uri->uri + 7);
 				else
