@@ -60,14 +60,18 @@ void textview_show_part		(TextView	*textview,
 				 FILE		*fp);
 void textview_show_mime_part	(TextView	*textview,
 				 MimeInfo	*partinfo);
+#if USE_GPGME
+void textview_show_signature_part(TextView	*textview,
+				  MimeInfo 	*partinfo);
+#endif
 void textview_clear		(TextView	*textview);
 void textview_destroy		(TextView	*textview);
-void textview_quote_color_set	(void);
 void textview_set_font		(TextView	*textview,
 				 const gchar	*codeset);
 void textview_scroll_one_line	(TextView	*textview,
 				 gboolean	 up);
 gboolean textview_scroll_page	(TextView	*textview,
 				 gboolean	 up);
+void textview_update_message_colors(void);
 
 #endif /* __TEXTVIEW_H__ */
